@@ -1,6 +1,6 @@
 package swat;
 
-our $VERSION = 'v0.1.27';
+our $VERSION = '0.1.28';
 
 use base 'Exporter'; 
 
@@ -18,6 +18,7 @@ use strict;
 use Test::More;
 
 our $HTTP_RESPONSE;
+our ($project);
 our ($curl_cmd, $content_file);
 our ($url, $path, $http_meth); 
 our ($debug, $ignore_http_err, $try_num, $debug_bytes);
@@ -103,7 +104,7 @@ sub check_line {
 
 sub header {
 
-    diag("start swat for $url/$path | is swat package $is_swat_package");
+    diag("start swat for $url/$path | project $project | is swat package $is_swat_package");
     diag("swat version $swat::VERSION | debug $debug | try num $try_num | ignore http errors $ignore_http_err")
 }
 
@@ -305,31 +306,26 @@ produces L<TAP|https://testanything.org/> output
 
 leverages famous L<perl prove|http://search.cpan.org/perldoc?prove> and L<curl|http://curl.haxx.se/> utilities
 
-
-=item *
-
-has minimal dependency tree  and probably will run out of the box on most linux environments, provided that one has perl/bash/find/curl by hand ( which is true  for most cases )
-
-
 =back
 
+=head1 Install
 
-=head1 Tutorial
+Swat relies on curl utility to make http requests. Thus first you need to install curl:
 
+    $ sudo apt-get install curl
 
-=head2 Install swat
+Also swat client is bash script so you need a bash. 
 
-
-=head3 stable release
+Then you install swat cpan module:
 
     sudo cpan install swat
 
-=head3 developer release
+=head2 Developer release
 
     # developer release might be untested and unstable
     sudo cpanm --mirror-only --mirror https://stratopan.com/melezhik/swat-release/master swat
 
-=head3 install from source
+=head2 Install from source
 
     # useful for contributors
     perl Makefile.PL
@@ -337,8 +333,9 @@ has minimal dependency tree  and probably will run out of the box on most linux
     make test
     make install
 
-Once swat is installed you have B<swat> command line tool to run swat tests, but before do this you need to create them.
+=head1 Swat mini tutorial
 
+For those who love to make long story short ...
 
 =head2 Create tests
 
@@ -859,7 +856,6 @@ C<prove_options> - prove options, default value is C<-v>
 
 
 
-
 =back
 
 
@@ -905,14 +901,14 @@ Thus swat.ini file should be bash file with swat variables definitions. Here is
 
 =head2 Settings priority table
 
-This table describes order in which settings are applied, statrs from lowest priority settings
+This table describes order in which settings are applied, starts from lowest priority settings
 
     | context                 | location                | settings type        | priority  level |
     | ------------------------|------------------------ | -------------------- | ----------------
     | swat.ini file           | ~/swat.ini              | home directory       |       1         |
-    | environment variables   | ---                     | session              |       2         |
-    | swat.ini file           | project root directory  | project based        |       3         |
-    | swat.ini file           | route directory         | route based          |       4         |
+    | swat.ini file           | project root directory  | project based        |       2         |
+    | swat.ini file           | route directory         | route based          |       3         |
+    | environment variables   | ---                     | session              |       4         |
 
 
 =head1 Settings merge algorithm
@@ -932,18 +928,18 @@ Clear a designated set of settings:
     curl_max_time
     curl_params
 
-=item *
-
-Apply environmental settings if exist
-
 
 =item *
 
-Apply project based settings if exist
+Apply project based settings if exist.
 
 =item *
 
-And finally apply route based settings if exist
+Apply route based settings if exist.
+
+=item *
+
+And finally apply environmental settings if exist.
 
 =back
 
@@ -985,7 +981,7 @@ B<swat_package> - the name of swat package, see L</"Swat Packages"> section
 
 =head2 Default Host
 
-Sometimes it is helpfull to not setup host as command line parameter but define it at $project_root/host file. For example:
+Sometimes it is helpful to not setup host as command line parameter but define it at $project_root/host file. For example:
 
 
     # let's create a default host for foo/bar project
@@ -1018,49 +1014,39 @@ This is mini how-to on creating swat packages:
 
 =head2 Create swat package
 
-Let's imagine you've got ready swat tests you want to distribute. First of all you need to create _tar.gz archive_ of
-swat project root directory:
+Swat packages are I<just cpan modules>. So all you need is to create cpan module distribution archive and upload it to CPAN.
 
-    tar -zcf $project_root_dir.tar.gz project_root_dir
+The only requirement for installer is that swat data files should be installed into I<cpan module directory> at the end of install process. 
+L<File::ShareDir::Install|http://search.cpan.org/perldoc?File%3A%3AShareDir%3A%3AInstall> allows you to install 
+read-only data files from a distribution and considered as best practice for such a things.
 
-For example for project ./examples/google 
+Here is example of Makefile.PL for L<swat::mongodb package|https://github.com/melezhik/swat-packages/tree/master/mongodb-http>:
 
-    cd ./examples/
-    tar -zcf google.tar.gz ./google
 
-=head2 Upload package to swat repository
+    use inc::Module::Install;
 
-Swat repository might be  _ANY_ web server. One should upload archive into server.
-Let's say we have nginx server. The example below is for debian:
+    # Define metadata
+    name           'swat-mongodb';
+    all_from       'lib/swat/mongodb.pm';
 
-    # install nginx:
-    sudo apt-get install nginx
+    # Specific dependencies
+    requires       'swat'         => '0.1.28';
+    test_requires  'Test::More'   => '0';
 
-    # copy swat distributive:
-    sudo cp google.tar.gz /var/www/html/
+    install_share  'module' => 'swat::mongodb', 'share';    
 
-    # check for archive availability over web server:
-    curl -s 127.0.0.1/google.tar.gz -D - -o /dev/null  | head  -n 1
-    HTTP/1.1 200 OK
+    license 'perl';
 
-You swat repository with nginx swat package uploaded is ready!
+    WriteAll;
 
-=head2 Install swat package
+Here we create a swat package swat::mongodb with swat data files kept in the project_root directory ./share and get installed into
+C<auto/share/module/swat-mongodb> directory.
 
-Swat comes with utility called B<swatman> to manage swat packages. 
-First of all one need to setup swat repository:
 
-    echo "swat_repo=127.0.0.1" >> ~/swat.ini
+Once we uploaded a module to CPAN repository we can use it: 
 
-Then install package
-
-    swatman install google
-
-=head2 Run swat tests
-
-Once swat package is installed into your system you may give it a run:
-
-    swat google google.ru
+    $ cpan install swat::mongodb
+    $ swat swat::mongodb 127.0.0.1:28017
 
 =head1 Debugging
 
@@ -1071,39 +1057,6 @@ set C<swat_debug> environmental variable to 1
 
 ./examples directory contains examples of swat tests for different cases. Follow README.md files for details.
 
-
-=head1 Dependencies
-
-Not that many :)
-
-=over
-
-=item *
-
-perl 
-
-=item *
-
-curl 
-
-=item *
-
-bash
-
-=item *
-
-find
-
-=item *
-
-head
-
-=item *
-
-tar
-
-=back
-
 =head1 AUTHOR
 
 L<Aleksei Melezhik|mailto:melezhik@gmail.com>
